@@ -142,7 +142,7 @@ class TalismanDocument(AbstractTalismanDocument[_Content], Generic[_Content]):
 
     def filter_directives(self, type_: Type[_Directive], filter_: Callable[[_Directive], bool] = lambda _: True) -> Iterator[_Directive]:
         for directive in self._directives:
-            if directive.directive_type is type_ and filter_(directive):
+            if isinstance(directive, type_) and filter_(directive):
                 yield directive
 
     def with_directives(self: _TalismanDocument, directives: Iterable[AbstractDirective]) -> _TalismanDocument:
